==> appfs-21.02.tar.gz: usr/local/www/berogui/modules/Lte/lte_submit.php <==
<?php

include ('/usr/local/www/berogui/includes/Helper/Helper.php');
include ('/usr/local/www/berogui/includes/Helper/HelperPstn.php');

$exec_ajax = 1;
$invalid = array();

/* [CHECKING GET REQUEST] */
unset($_GET);

/* [CHECKING SESSION] */
$newTarget = '/app/berogui/index.php?m=Lte';
require_once('/usr/local/www/berogui/includes/session.php');
unset($newTarget);

/* [CHECKING POST REQUEST] */
unset($_POST['submit']);

$general_post = HelperPstn::getPostParameters('general');
$lte_post     = HelperPstn::getPostParameters('lte');

$_POST = Helper::sanitizePost($_POST, array_merge($general_post['post'], $lte_post['post']), $exec_ajax, $invalid, array_merge($general_post['options'], $lte_post['options']));

/* [EXECUTING AJAX] */
if (!$exec_ajax) {
        echo "<script>window.location='../../index.php?m=Lte&error=1&request={$invalid['request']}&checkor={$invalid['checkor']}&key={$invalid['key']}'</script>";
        exit(1);
}

// LTE-Einträge speichern
chdir('../..');

include "./includes/variables.php";
include_once("/usr/www/include/SQLite2ToSQLite3.php");
include "./misc/database.php";
require_once "./includes/isgwtelnet.php";
$ba = new beroAri();

function parameters($config = "") {
	foreach ($_POST as $key => $value) {
		$_POST[$key] = str_replace("'", "\"", $_POST[$key]);
	}


	//Additional config string hinzufügen.
	if ($_POST['addit_options'] != "")
		$config .= "," . str_replace(array("\r\n", "\n", "\r"), ",", $_POST['addit_options']);

	return $config;
}

if (strtolower($_POST['group']) == "general") {
	echo "<script>alert('Invalid Group Name');  window.history.back();</script>";
	return;
}
$query_comp = $ba->select("SELECT gr FROM lte");
while ($entry = $ba->fetch_array($query_comp)) {
	if ($_POST['gr_upd'] != $entry['gr']) {
		if ($_POST['group'] == $entry['gr']) {
			echo "<script>alert('Invalid Group Name');  window.history.back();</script>";
			return;
		}
	}
}
if ($_POST['gr_upd'] != "") {
	$query_new = $ba->update('UPDATE lte SET gr=\'NULL\', config=\'\' WHERE gr=\'' . sqlite_escape_string($_POST['gr_upd']) . '\'');
}
$gr = $_POST['group'];
$sms_extension = $_POST['sms_extension'];
$extension = $_POST['extension'];
$ports = $_POST['ports'];
$chansel = $_POST['chansel'];
$chansel_dir = $_POST['chansel_dir'];
$sms_webhook = $_POST['sms_webhook'];

$port = "";
$config = parameters();

for ($i = 0; $i < count($ports); $i++) {
	$port = $ports[$i];
	$query_new = $ba->update('UPDATE lte SET gr=\'' . sqlite_escape_string($gr) . '\', config=\'' . sqlite_escape_string($config) . '\', sms_extension=\'' 
		. sqlite_escape_string($sms_extension) . '\', extension=\'' . sqlite_escape_string($extension) . '\', chansel=\'' 
		. sqlite_escape_string($chansel) . '\', chansel_dir=\'' . sqlite_escape_string($chansel_dir)  . '\', sms_webhook=\'' . sqlite_escape_string($sms_webhook) . '\' WHERE port=\'' . sqlite_escape_string($port) . '\'');
}

if (!$ba->is_error() && $_POST['gr_upd'] != "") {
	$query = $ba->update('UPDATE dialplan SET fromId=\'g:' . sqlite_escape_string($gr) . '\' where fromDirection=\'lte\' and fromId=\'g:' . sqlite_escape_string($_POST['gr_upd']) . '\'');
	$query = $ba->update('UPDATE dialplan SET toId=\'g:' . sqlite_escape_string($gr) . '\' where toDirection=\'lte\' and toId=\'g:' . sqlite_escape_string($_POST['gr_upd']) . '\'');
}

Helper::activate(2);
if (!$ba->is_error()) {
	echo "<script>window.location='../../index.php?m=Lte'</script>";
} else {
	echo "<script>alert(" . $ba->error() . ");</script>";
}
?>

==> appfs-24.01.01-rc42.tar.gz: usr/local/www/berogui/modules/Lte/lte_submit.php <==
<?php

include ('/usr/local/www/berogui/includes/Helper/Helper.php');
include ('/usr/local/www/berogui/includes/Helper/HelperPstn.php');

$exec_ajax = 1;
$invalid = array();

/* [CHECKING GET REQUEST] */
unset($_GET);
/* [CHECKING SESSION] */
$newTarget = '/app/berogui/index.php?m=Lte';
require_once('/usr/local/www/berogui/includes/session.php');
unset($newTarget);

/* [CHECKING POST REQUEST] */
unset($_POST['submit']);

$general_post = HelperPstn::getPostParameters('general');
$lte_post     = HelperPstn::getPostParameters('lte');

$_POST = Helper::sanitizePost($_POST, array_merge($general_post['post'], $lte_post['post']), $exec_ajax, $invalid, array_merge($general_post['options'], $lte_post['options']));

/* [EXECUTING AJAX] */
if (!$exec_ajax) {
        echo "<script>window.location='../../index.php?m=Lte&error=1&request={$invalid['request']}&checkor={$invalid['checkor']}&key={$invalid['key']}'</script>";
        exit(1);
}

// LTE-Einträge speichern
chdir('../..');

include "./includes/variables.php";
include_once("/usr/www/include/SQLite2ToSQLite3.php");
include "./misc/database.php";
require_once "./includes/isgwtelnet.php";
$ba = new beroAri();
function parameters($config = "") {
	foreach ($_POST as $key => $value) {
		$_POST[$key] = str_replace("'", "\"", $_POST[$key]);
	}


	//Additional config string hinzufügen.
	if ($_POST['addit_options'] != "")
		$config .= "," . str_replace(array("\r\n", "\n", "\r"), ",", $_POST['addit_options']);

	return $config;
}

if (strtolower($_POST['group']) == "general") {
	echo "<script>alert('Invalid Group Name');  window.history.back();</script>";
	return;
}
$query_comp = $ba->select("SELECT gr FROM lte");
while ($entry = $ba->fetch_array($query_comp)) {
	if ($_POST['gr_upd'] != $entry['gr']) {
		if ($_POST['group'] == $entry['gr']) {
			echo "<script>alert('Invalid Group Name');  window.history.back();</script>";
			return;
		}
	}
}
if ($_POST['gr_upd'] != "") {
	$query_new = $ba->update('UPDATE lte SET gr=\'NULL\', config=\'\' WHERE gr=\'' . sqlite_escape_string($_POST['gr_upd']) . '\'');
}
$gr = $_POST['group'];
$sms_extension = $_POST['sms_extension'];
$extension = $_POST['extension'];
$ports = $_POST['ports'];
$chansel = $_POST['chansel'];
$chansel_dir = $_POST['chansel_dir'];
$sms_webhook = $_POST['sms_webhook'];
$sms_webhook_user = $_POST['sms_webhook_user'];
$sms_webhook_secret = $_POST['sms_webhook_secret'];
$sms_webhook_type = $_POST['sms_webhook_type'];
$sms_webhook_id = $_POST['sms_webhook_id'];
$wait_for_cid_timeout = $_POST['wait_for_cid_timeout'];
$lte_init_hook = str_replace(array ("\r\n", "\r", "\n"), "\t", $_POST['lte_init_hook']);

$port = "";
$config = parameters();

for ($i = 0; $i < count($ports); $i++) {
	$port = $ports[$i];
	$query_new = $ba->update('UPDATE lte SET gr=\'' . sqlite_escape_string($gr) . '\', config=\'' . sqlite_escape_string($config) . '\', sms_extension=\'' 
		. sqlite_escape_string($sms_extension) . '\', extension=\'' . sqlite_escape_string($extension) . '\', chansel=\'' 
		. sqlite_escape_string($chansel) . '\', chansel_dir=\'' . sqlite_escape_string($chansel_dir)  . '\', sms_webhook=\'' . sqlite_escape_string($sms_webhook) . '\' , sms_webhook_user=\'' . sqlite_escape_string($sms_webhook_user) . '\' , sms_webhook_secret=\'' . sqlite_escape_string($sms_webhook_secret) . '\' , sms_webhook_type=\'' . sqlite_escape_string($sms_webhook_type) . '\' , sms_webhook_id=\'' . sqlite_escape_string($sms_webhook_id) . '\' , wait_for_cid_timeout=\'' . sqlite_escape_string($wait_for_cid_timeout) . '\' , lte_init_hook=\'' . sqlite_escape_string($lte_init_hook) . '\' WHERE port=\'' . sqlite_escape_string($port) . '\'');
}

if (!$ba->is_error() && $_POST['gr_upd'] != "") {
	$query = $ba->update('UPDATE dialplan SET fromId=\'g:' . sqlite_escape_string($gr) . '\' where fromDirection=\'lte\' and fromId=\'g:' . sqlite_escape_string($_POST['gr_upd']) . '\'');
	$query = $ba->update('UPDATE dialplan SET toId=\'g:' . sqlite_escape_string($gr) . '\' where toDirection=\'lte\' and toId=\'g:' . sqlite_escape_string($_POST['gr_upd']) . '\'');
}

Helper::activate(2);
if (!$ba->is_error()) {
	echo "<script>window.location='../../index.php?m=Lte'</script>";
} else {
	echo "<script>alert(" . $ba->error() . ");</script>";
}
?>
